autowisp.fit_expression.interface module — AutoWISP documentation

# autowisp.fit_expression.interface module

## Class Inheritance Diagram

An interface for working with fitting terms expressions.

class autowisp.fit_expression.interface.Interface(expression)

  Bases: `object`

  Interface class for working with fit terms expressions.

  _number_terms

    Once terms are counted, this attribute stores the result for re-use.

  __call__(*data)

    Return an array of the term values for the given data.

  __init__(expression)

    Create an interface for working with the given expression.

  get_term_str_list()

    Return strings of the individual terms the expression expands to.

  get_var_names()

    Return the names of the variables used in expression.

  number_terms()

    Return the number of terms the expression expands to.